import { useState } from 'react';

// 运行时配置
export async function getInitialState(): Promise<{ name: string }> {
  return { name: '@umijs/max' };
}

export function useQiankunStateForSlave() {
  const [globalState, setGlobalState] = useState<any>({
    slogan: 'qiankun father',
  });

  return {
    globalState,
    setGlobalState,
  };
}

const env = process.env.NODE_ENV;

export const qiankun = {
  apps: [
    {
      name: 'intelligent-file-cabinet', // 盒子管理
      entry:
        env === 'production'
          ? '//localhost:30068/intelligent-file-cabinet/'
          : '//localhost:30068/',
      props: {},
    },
    {
      name: 'algorithm-warehouse', // AI 算法分析
      entry:
        env === 'production'
          ? '//localhost:30078/smart-video-analysis/'
          : '//localhost:30078/',
    },
    {
      name: 'smart-video-analysis', // AI 智能分析仓
      entry:
        env === 'production'
          ? '//localhost:30088/algorithm-warehouse/'
          : '//localhost:30088/',
    },
    {
      name: 'communal-facilities-pages', // 物料库
      entry:
        env === 'production'
          ? '//localhost:30098/communal-facilities-pages/'
          : '//localhost:30098/',
    },
  ],
  lifeCycles: {
    // 所有子应用在挂载完成时，打印 props 信息
    async afterMount(props: any) {
      console.log('主应用:', props);
    },
  },
};
